@@ -10,7 +10,7 @@ def get_geneOntology(gene_symbol):
     Associated GO terms for gene(s) of interest. QuickGO - a fast web-based browser of the Gene Ontology and Gene Ontology annotation data - is used as external source.
     :param gene_symbol: A list of gene symbol(s). Required parameter.
     :example: Get all GO terms associated with gene(s) of interest.
-              get_geneOntology(gene_symbol=["SEPT7P1","TIGAR"])
+              get_geneOntology(gene_symbol=["PTEN","TIGAR"])
     """
 
     params = {}
@@ -29,5 +29,5 @@ def get_geneOntology(gene_symbol):
     if response.status_code == 200:
         return data
     else:
-        if response.status_code == 404:
+        if response.status_code == 202:
             raise ValueError("API response is empty. Reason: " + data["detail"].values)
\ No newline at end of file
